@@ -36,8 +36,13 @@ from braket.device_schema.ionq import IonqDeviceParameters
 from braket.device_schema.oqc import OqcDeviceParameters
 from braket.device_schema.rigetti import RigettiDeviceParameters
 from braket.device_schema.simulators import GateModelSimulatorDeviceParameters
+from braket.ir.blackbird import Program as BlackbirdProgram
 from braket.ir.openqasm import Program as OpenQasmProgram
-from braket.tasks import AnnealingQuantumTaskResult, GateModelQuantumTaskResult
+from braket.tasks import (
+    AnnealingQuantumTaskResult,
+    GateModelQuantumTaskResult,
+    PhotonicModelQuantumTaskResult,
+)
 
 S3_TARGET = AwsSession.S3DestinationFolder("foo", "bar")
 
@@ -45,6 +50,7 @@ IONQ_ARN = "device/qpu/ionq"
 RIGETTI_ARN = "device/qpu/rigetti"
 OQC_ARN = "device/qpu/oqc"
 SIMULATOR_ARN = "device/quantum-simulator"
+XANADU_ARN = "device/qpu/xanadu"
 
 DEVICE_PARAMETERS = [
     (IONQ_ARN, IonqDeviceParameters),
@@ -76,6 +82,11 @@ def annealing_task(aws_session):
     return AwsQuantumTask("foo:bar:arn", aws_session, poll_timeout_seconds=2)
 
 
+@pytest.fixture
+def photonic_model_task(aws_session):
+    return AwsQuantumTask("foo:bar:arn", aws_session, poll_timeout_seconds=2)
+
+
 @pytest.fixture
 def arn():
     return "foo:bar:arn"
@@ -96,6 +107,11 @@ def openqasm_program():
     return OpenQasmProgram(source="OPENQASM 3.0; h $0;")
 
 
+@pytest.fixture
+def blackbird_program():
+    return BlackbirdProgram(source="Vac | q[0]")
+
+
 def test_equality(arn, aws_session):
     quantum_task_1 = AwsQuantumTask(arn, aws_session)
     quantum_task_2 = AwsQuantumTask(arn, aws_session)
@@ -231,6 +247,20 @@ def test_result_annealing(annealing_task):
     )
 
 
+def test_result_photonic_model(photonic_model_task):
+    _mock_metadata(photonic_model_task._aws_session, "COMPLETED")
+    _mock_s3(photonic_model_task._aws_session, MockS3.MOCK_S3_RESULT_PHOTONIC_MODEL)
+
+    expected = PhotonicModelQuantumTaskResult.from_string(MockS3.MOCK_S3_RESULT_PHOTONIC_MODEL)
+    assert photonic_model_task.result() == expected
+
+    s3_bucket = photonic_model_task.metadata()["outputS3Bucket"]
+    s3_object_key = photonic_model_task.metadata()["outputS3Directory"]
+    photonic_model_task._aws_session.retrieve_s3_object_body.assert_called_with(
+        s3_bucket, f"{s3_object_key}/results.json"
+    )
+
+
 @pytest.mark.xfail(raises=TypeError)
 def test_result_invalid_type(circuit_task):
     _mock_metadata(circuit_task._aws_session, "COMPLETED")
@@ -379,6 +409,20 @@ def test_create_openqasm_program(aws_session, arn, openqasm_program):
     )
 
 
+def test_create_blackbird_program(aws_session, arn, blackbird_program):
+    aws_session.create_quantum_task.return_value = arn
+    shots = 21
+    AwsQuantumTask.create(aws_session, XANADU_ARN, blackbird_program, S3_TARGET, shots)
+
+    _assert_create_quantum_task_called_with(
+        aws_session,
+        XANADU_ARN,
+        blackbird_program.json(),
+        S3_TARGET,
+        shots,
+    )
+
+
 @pytest.mark.parametrize("device_arn,device_parameters_class", DEVICE_PARAMETERS)
 def test_from_circuit_with_shots(device_arn, device_parameters_class, aws_session, circuit):
     mocked_task_arn = "task-arn-1"
@@ -432,9 +476,12 @@ def test_from_circuit_with_disabled_rewiring(
 
 
 @pytest.mark.parametrize(
-    "device_arn,device_parameters_class", [(RIGETTI_ARN, RigettiDeviceParameters)]
+    "device_arn,device_parameters_class, disable_qubit_rewiring",
+    [(RIGETTI_ARN, RigettiDeviceParameters, True), (RIGETTI_ARN, RigettiDeviceParameters, False)],
 )
-def test_from_circuit_with_verbatim(device_arn, device_parameters_class, aws_session):
+def test_from_circuit_with_verbatim(
+    device_arn, device_parameters_class, disable_qubit_rewiring, aws_session
+):
     circ = Circuit().add_verbatim_box(Circuit().h(0))
     mocked_task_arn = "task-arn-1"
     aws_session.create_quantum_task.return_value = mocked_task_arn
@@ -446,7 +493,7 @@ def test_from_circuit_with_verbatim(device_arn, device_parameters_class, aws_ses
         circ,
         S3_TARGET,
         shots,
-        disable_qubit_rewiring=True,
+        disable_qubit_rewiring=disable_qubit_rewiring,
     )
     assert task == AwsQuantumTask(mocked_task_arn, aws_session)
 
@@ -458,19 +505,12 @@ def test_from_circuit_with_verbatim(device_arn, device_parameters_class, aws_ses
         shots,
         device_parameters_class(
             paradigmParameters=GateModelParameters(
-                qubitCount=circ.qubit_count, disableQubitRewiring=True
+                qubitCount=circ.qubit_count, disableQubitRewiring=disable_qubit_rewiring
             )
         ),
     )
 
 
-@pytest.mark.xfail(raises=ValueError)
-def test_from_circuit_with_verbatim_qubit_rewiring_not_disabled(aws_session):
-    circ = Circuit().add_verbatim_box(Circuit().h(0))
-    shots = 57
-    AwsQuantumTask.create(aws_session, RIGETTI_ARN, circ, S3_TARGET, shots)
-
-
 @pytest.mark.xfail(raises=ValueError)
 def test_from_circuit_with_shots_value_error(aws_session, arn, circuit):
     mocked_task_arn = "task-arn-1"
